@@ -3,7 +3,7 @@
  * EVENTS.C - Timed event functions for Nagios
  *
  * Copyright (c) 1999-2007 Ethan Galstad (nagios@nagios.org)
- * Last Modified:   03-05-2007
+ * Last Modified:   01-08-2007
  *
  * License:
  *
@@ -1288,11 +1288,7 @@ int handle_timed_event(timed_event *event){
 #endif
 
 		/* process scheduled downtime info */
-		if(event->event_data){
-			handle_scheduled_downtime_by_id(*(unsigned long *)event->event_data);
-			free(event->event_data);
-			event->event_data=NULL;
-			}
+		handle_scheduled_downtime_by_id((unsigned long)event->event_data);
 		break;
 
 	case EVENT_SFRESHNESS_CHECK:
