@@ -3,12 +3,12 @@
  * NAGIOS.C - Core Program Code For Nagios
  *
  * Program: Nagios
- * Version: 2.4
+ * Version: 2.7
  * License: GPL
- * Copyright (c) 1999-2006 Ethan Galstad (http://www.nagios.org)
+ * Copyright (c) 1999-2007 Ethan Galstad (http://www.nagios.org)
  *
  * First Written:   01-28-1999 (start of development)
- * Last Modified:   05-31-2006
+ * Last Modified:   01-19-2007
  *
  * Description:
  *
@@ -207,6 +207,8 @@ service_message svc_msg;
 circular_buffer  external_command_buffer;
 circular_buffer  service_result_buffer;
 pthread_t worker_threads[TOTAL_WORKER_THREADS];
+int              external_command_buffer_slots=DEFAULT_EXTERNAL_COMMAND_BUFFER_SLOTS;
+int              check_result_buffer_slots=DEFAULT_CHECK_RESULT_BUFFER_SLOTS;
 
 
 
@@ -284,7 +286,7 @@ int main(int argc, char **argv){
 
 	if(daemon_mode==FALSE){
 		printf("\nNagios %s\n",PROGRAM_VERSION);
-		printf("Copyright (c) 1999-2006 Ethan Galstad (http://www.nagios.org)\n");
+		printf("Copyright (c) 1999-2007 Ethan Galstad (http://www.nagios.org)\n");
 		printf("Last Modified: %s\n",PROGRAM_MODIFICATION_DATE);
 		printf("License: GPL\n\n");
 	        }
