@@ -2,8 +2,8 @@
  *
  * CGIUTILS.C - Common utilities for Nagios CGIs
  * 
- * Copyright (c) 1999-2004 Ethan Galstad (nagios@nagios.org)
- * Last Modified: 11-05-2004
+ * Copyright (c) 1999-2006 Ethan Galstad (nagios@nagios.org)
+ * Last Modified: 11-12-2006
  *
  * License:
  *
@@ -1178,9 +1178,9 @@ int mmap_fclose(mmapfile *temp_mmapfile){
 
 /* gets one line of input from an mmap()'ed file */
 char *mmap_fgets(mmapfile *temp_mmapfile){
-	char *buf;
-	unsigned long x;
-	int len;
+	char *buf=NULL;
+	unsigned long x=0L;
+	int len=0;
 
 	if(temp_mmapfile==NULL)
 		return NULL;
@@ -1191,23 +1191,25 @@ char *mmap_fgets(mmapfile *temp_mmapfile){
 
 	/* find the end of the string (or buffer) */
 	for(x=temp_mmapfile->current_position;x<temp_mmapfile->file_size;x++){
-		if(*(char *)(temp_mmapfile->mmap_buf+x)=='\n')
+		if(*((char *)(temp_mmapfile->mmap_buf)+x)=='\n'){
+			x++;
 			break;
+			}
 	        }
 
 	/* calculate length of line we just read */
-	len=(int)x-temp_mmapfile->current_position+1;
+	len=(int)(x-temp_mmapfile->current_position);
 
 	/* allocate memory for the new line */
 	if((buf=(char *)malloc(len+1))==NULL)
 		return NULL;
 
 	/* copy string to newly allocated memory and terminate the string */
-	memcpy(buf,(char *)(temp_mmapfile->mmap_buf+temp_mmapfile->current_position),len);
+	memcpy(buf,((char *)(temp_mmapfile->mmap_buf)+temp_mmapfile->current_position),len);
 	buf[len]='\x0';
 
 	/* update the current position */
-	temp_mmapfile->current_position=x+1;
+	temp_mmapfile->current_position=x;
 
 	/* increment the current line */
 	temp_mmapfile->current_line++;
@@ -1559,7 +1561,7 @@ void display_info_table(char *title,int refresh, authdata *current_authdata){
 	int result;
 
 	/* read program status */
-	result=read_all_status_data(DEFAULT_CGI_CONFIG_FILE,READ_PROGRAM_STATUS);
+	result=read_all_status_data(get_cgi_config_location(),READ_PROGRAM_STATUS);
 
 	printf("<TABLE CLASS='infoBox' BORDER=1 CELLSPACING=0 CELLPADDING=0>\n");
 	printf("<TR><TD CLASS='infoBox'>\n");
