@@ -3,7 +3,7 @@
  * DOWNTIME.C - Scheduled downtime functions for Nagios
  *
  * Copyright (c) 2000-2007 Ethan Galstad (nagios@nagios.org)
- * Last Modified: 03-05-2007
+ * Last Modified: 01-08-2007
  *
  * License:
  *
@@ -205,18 +205,10 @@ int unschedule_downtime(int type,unsigned long downtime_id){
 		delete_service_downtime(downtime_id);
 
 	/* unschedule all downtime entries that were triggered by this one */
-	while(1){
-
-		for(temp_downtime=scheduled_downtime_list;temp_downtime!=NULL;temp_downtime=temp_downtime->next){
-			if(temp_downtime->triggered_by==downtime_id){
-				unschedule_downtime(ANY_DOWNTIME,temp_downtime->downtime_id);
-				break;
-				}
-			}
-
-		if(temp_downtime==NULL)
-			break;
-		}
+	for(temp_downtime=scheduled_downtime_list;temp_downtime!=NULL;temp_downtime=temp_downtime->next){
+		if(temp_downtime->triggered_by==downtime_id)
+			unschedule_downtime(ANY_DOWNTIME,temp_downtime->downtime_id);
+	        }
 
 	return OK;
         }
@@ -234,7 +226,6 @@ int register_downtime(int type, unsigned long downtime_id){
 	char *type_string="";
 	int hours;
 	int minutes;
-	unsigned long *new_downtime_id=NULL;
 
 	/* find the downtime entry in memory */
 	temp_downtime=find_downtime(type,downtime_id);
@@ -281,12 +272,8 @@ int register_downtime(int type, unsigned long downtime_id){
 	/*** SCHEDULE DOWNTIME - FLEXIBLE (NON-FIXED) DOWNTIME IS HANDLED AT A LATER POINT ***/
 
 	/* only non-triggered downtime is scheduled... */
-	if(temp_downtime->triggered_by==0){
-		if((new_downtime_id=(unsigned long *)malloc(sizeof(unsigned long *)))){
-			*new_downtime_id=downtime_id;
-			schedule_new_event(EVENT_SCHEDULED_DOWNTIME,TRUE,temp_downtime->start_time,FALSE,0,NULL,FALSE,(void *)new_downtime_id,NULL);
-			}
-		}
+	if(temp_downtime->triggered_by==0)
+		schedule_new_event(EVENT_SCHEDULED_DOWNTIME,TRUE,temp_downtime->start_time,FALSE,0,NULL,FALSE,(void *)temp_downtime->downtime_id,NULL);
 
 	return OK;
         }
@@ -314,7 +301,6 @@ int handle_scheduled_downtime(scheduled_downtime *temp_downtime){
 	host *hst=NULL;
 	service *svc=NULL;
 	time_t event_time;
-	unsigned long *new_downtime_id=NULL;
 #ifdef USE_EVENT_BROKER
 	int attr;
 #endif
@@ -415,19 +401,10 @@ int handle_scheduled_downtime(scheduled_downtime *temp_downtime){
 		        }
 
 		/* handle (stop) downtime that is triggered by this one */
-		while(1){
-
-			/* list contents might change by recursive calls, so we use this inefficient method to prevent segfaults */
-			for(this_downtime=scheduled_downtime_list;this_downtime!=NULL;this_downtime=this_downtime->next){
-				if(this_downtime->triggered_by==temp_downtime->downtime_id){
-					handle_scheduled_downtime(this_downtime);
-					break;
-					}
-				}
-
-			if(this_downtime==NULL)
-				break;
-			}
+		for(this_downtime=scheduled_downtime_list;this_downtime!=NULL;this_downtime=this_downtime->next){
+			if(this_downtime->triggered_by==temp_downtime->downtime_id)
+				handle_scheduled_downtime(this_downtime);
+		        }
 
 		/* delete downtime entry from the log */
 		if(temp_downtime->type==HOST_DOWNTIME)
@@ -480,10 +457,7 @@ int handle_scheduled_downtime(scheduled_downtime *temp_downtime){
 			event_time=(time_t)((unsigned long)time(NULL)+temp_downtime->duration);
 		else
 			event_time=temp_downtime->end_time;
-		if((new_downtime_id=(unsigned long *)malloc(sizeof(unsigned long *)))){
-			*new_downtime_id=temp_downtime->downtime_id;
-			schedule_new_event(EVENT_SCHEDULED_DOWNTIME,TRUE,event_time,FALSE,0,NULL,FALSE,(void *)new_downtime_id,NULL);
-			}
+		schedule_new_event(EVENT_SCHEDULED_DOWNTIME,TRUE,event_time,FALSE,0,NULL,FALSE,(void *)temp_downtime->downtime_id,NULL);
 
 		/* handle (start) downtime that is triggered by this one */
 		for(this_downtime=scheduled_downtime_list;this_downtime!=NULL;this_downtime=this_downtime->next){
@@ -864,10 +838,6 @@ int add_downtime(int downtime_type, char *host_name, char *svc_description, time
 	if(triggered_by>0  && find_downtime(ANY_DOWNTIME,triggered_by)==NULL)
 		return ERROR;
 
-	/* we don't have enough info */
-	if(host_name==NULL || (downtime_type==SERVICE_DOWNTIME && svc_description==NULL))
-		return ERROR;
-
 	/* allocate memory for the downtime */
 	new_downtime=(scheduled_downtime *)malloc(sizeof(scheduled_downtime));
 	if(new_downtime==NULL)
